# The current git HEAD for RMG-Py (branch: master) is:
#	2fa3e92f419cc1e9c4d144235f719c84fa944b17
#	Fri Jul 13 17:59:38 2018 -0400
# The current git HEAD for RMG-database (branch: SABIC_2018) is:
#	86d4efcf759de79e8b3da3480c9e60abd226031f
#	Mon Jul 16 14:00:36 2018 -0400

# Data sources
database( 
    thermoLibraries = ['FFCM1(-)','BurkeH2O2','primaryThermoLibrary','DFT_QCI_thermo','CBS_QB3_1dHR'],
    reactionLibraries = [('FFCM1(-)',False),('BurkeH2O2inArHe',False),('2005_Senosiain_OH_C2H2',False)], 
    #seedMechanisms = [],
    kineticsDepositories = ['training'],
    kineticsFamilies = 'default', 
    kineticsEstimator = 'rate rules', 
)

generatedSpeciesConstraints(
    allowed = ['seed mechanisms','reaction libraries', 'input species'],
    maximumCarbonAtoms=7,
    maximumRadicalElectrons=1,
    allowSingletO2 = False,
)

# List of species
species(
    label='O2',
    reactive=True,
    structure=SMILES("[O][O]"),
)
species(
    label='CO',
    reactive=True,
    structure=SMILES("[C-]#[O+]"),
)
species(
    label='CO2',
    reactive=True,
    structure=SMILES("C(=O)=O"),
)
species(
    label='CH4',
    reactive=True,
    structure=SMILES("C"),
)
species(
    label='C2H2',
    reactive=True,
    structure=SMILES("C#C"),
)
species(
    label='C4H4',
    reactive=True,
    structure=SMILES("C#CC=C"),
)
species(
    label='C5H6',
    reactive=True,
    structure=SMILES("C1C=CCC=1"),
)
species(
    label='C5H5',
    reactive=True,
    structure=SMILES("[CH]1C=CC=C1"),
)


# Bath gas
species(
    label='Ar',
    reactive=False,
    structure=InChI("InChI=1S/Ar"),
)

# Reaction systems
# case 1
simpleReactor(
    temperature=(1150,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9955,
        "CH4": 0.0025,
        "O2": 0.002,
        "C4H4": 0,
        "C5H6": 0,
        "C5H5": 0,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1400,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9955,
        "CH4": 0.0025,
        "O2": 0.002,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1600,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9955,
        "CH4": 0.0025,
        "O2": 0.002,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1800,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9955,
        "CH4": 0.0025,
        "O2": 0.002,
    },
    terminationTime=(2,'s'),
)

# case 2
simpleReactor(
    temperature=(1150,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9930,
        "CH4": 0.0025,
        "O2": 0.002,
	"CO2":0.0025,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1400,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9930,
        "CH4": 0.0025,
        "O2": 0.002,
	"CO2":0.0025,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1600,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9930,
        "CH4": 0.0025,
        "O2": 0.002,
	"CO2":0.0025,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1800,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9930,
        "CH4": 0.0025,
        "O2": 0.002,
	"CO2":0.0025,
    },
    terminationTime=(2,'s'),
)
# case 3
simpleReactor(
    temperature=(1150,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9875,
        "CH4": 0.0025,
        "O2": 0.0025,
	"CO":0.0025,
	"CO2":0.0050,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1400,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9875,
        "CH4": 0.0025,
        "O2": 0.0025,
	"CO":0.0025,
	"CO2":0.0050,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1600,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9875,
        "CH4": 0.0025,
        "O2": 0.0025,
	"CO":0.0025,
	"CO2":0.0050,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1800,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9875,
        "CH4": 0.0025,
        "O2": 0.0025,
	"CO":0.0025,
	"CO2":0.0050,
    },
    terminationTime=(2,'s'),
)
# case 4
simpleReactor(
    temperature=(1150,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9960,
        "CH4": 0.002,
        "O2": 0.0018,
	"C2H2":0.0002,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1400,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9960,
        "CH4": 0.002,
        "O2": 0.0018,
	"C2H2":0.0002,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1600,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9960,
        "CH4": 0.002,
        "O2": 0.0018,
	"C2H2":0.0002,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1800,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9960,
        "CH4": 0.002,
        "O2": 0.0018,
	"C2H2":0.0002,
    },
    terminationTime=(2,'s'),
)
# case 5
simpleReactor(
    temperature=(1150,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9954,
        "CH4": 0.0025,
        "O2": 0.00205,
	"C2H2":0.00005,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1400,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9954,
        "CH4": 0.0025,
        "O2": 0.00205,
	"C2H2":0.00005,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1600,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9954,
        "CH4": 0.0025,
        "O2": 0.00205,
	"C2H2":0.00005,
    },
    terminationTime=(2,'s'),
)
simpleReactor(
    temperature=(1800,'K'),
    pressure=(1.0,'bar'),
    initialMoleFractions={
        "Ar": 0.9954,
        "CH4": 0.0025,
        "O2": 0.00205,
	"C2H2":0.00005,
    },
    terminationTime=(2,'s'),
)


simulator(
    atol=1e-16,
    rtol=1e-8,
)

model(
    toleranceKeepInEdge=0.0008,
    toleranceMoveToCore=0.008,
    toleranceInterruptSimulation=1e8,
    maximumEdgeSpecies=100000,
    filterReactions=True,
)

pressureDependence(
        method='modified strong collision',
        maximumGrainSize=(0.5,'kcal/mol'),
        minimumNumberOfGrains=250,
        temperatures=(298,3000,'K',8),
        pressures=(0.1,100,'bar',6),
        interpolation=('Chebyshev', 6, 4),
)

options(
    units='si',
    saveRestartPeriod=None,
    generateOutputHTML=True,
    generatePlots=False,
    saveSimulationProfiles=False,
    saveEdgeSpecies=True,
)
